summaryrefslogtreecommitdiff
path: root/includes/Rts.h
diff options
context:
space:
mode:
Diffstat (limited to 'includes/Rts.h')
-rw-r--r--includes/Rts.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/includes/Rts.h b/includes/Rts.h
index 59edc09e83..7375798c62 100644
--- a/includes/Rts.h
+++ b/includes/Rts.h
@@ -270,11 +270,11 @@ extern void stg_exit(int n) GNU_ATTRIBUTE(__noreturn__);
-------------------------------------------------------------------------- */
typedef struct _StgEntCounter {
- /* krc: StgWord32, not StgWord16, in order to match the code
- generator, which doesn't generate anything of that type. */
- StgWord32 registeredp; /* 0 == no, 1 == yes */
- StgWord32 arity; /* arity (static info) */
- StgWord32 stk_args; /* # of args off stack */
+ /* Using StgWord for everything, becuase both the C and asm code
+ generators make trouble if you try to pack things tighter */
+ StgWord registeredp; /* 0 == no, 1 == yes */
+ StgInt arity; /* arity (static info) */
+ StgInt stk_args; /* # of args off stack */
/* (rest of args are in registers) */
char *str; /* name of the thing */
char *arg_kinds; /* info about the args types */